@@ -94,10 +94,14 @@ class BaseGeometry(object):
     def _is_empty(self):
         return self.__geom__ in [EMPTY, None]
 
+    # a reference to the so/dll proxy to preserve access during clean up
+    _lgeos = lgeos
+
     def empty(self):
+        # TODO: defer cleanup to the implementation. We shouldn't be
+        # explicitly calling a lgeos method here.
         if not (self._owned or self._is_empty):
-            from shapely.geos import lgeos
-            lgeos.GEOSGeom_destroy(self.__geom__)
+            self._lgeos.GEOSGeom_destroy(self.__geom__)
         self.__geom__ = EMPTY
 
     def __del__(self):
@@ -574,7 +578,6 @@ class HeterogeneousGeometrySequence(GeometrySequence):
         g._owned = True
         return g
 
-
 # Test runner
 def _test():
     import doctest
